@@ -197,7 +197,7 @@ void MFPlayerSession::load(const QMediaContent &media, QIODevice *stream)
     qDebug() << "load";
 #endif
     clear();
-    QUrl url = media.canonicalUrl();
+    QUrl url = media.request().url();
 
     if (m_status == QMediaPlayer::LoadingMedia && m_sourceResolver)
         m_sourceResolver->cancel();
